%define _localstatedir /var/lib
%define _bindir %{_libexecdir}/%{name}/bin
%define _sysconfdir /etc/%{name}

%if %{?mgaversion:0}%{?!mgaversion:1}
%global notmga 1
%endif

%global __requires_exclude %{?__requires_exclude:%__requires_exclude|}newgetopt.pl

# Note: most of the contents is noarch, but hpuifilter, par are c binaries

Name:		rancid
Version:	3.13
Release:	%mkrel 4
Summary:	Really Awesome New Cisco confIg Differ
Group:		Monitoring
License:	BSD-3-Clause
URL:		https://www.shrubbery.net/rancid/
Source:		https://shrubbery.net/pub/rancid/rancid-%{version}.tar.gz
Source1:	README.rancid.urpmi
Source2:	rancid-lg-httpd.conf
Patch0:		rancid-Makefile.patch
Patch1:		rancid-configure-no-ping-test.patch
Patch2:		rancid-3.13-dnos10-psu-filter.patch
Requires:	cvs expect >= 5.40
Recommends:	subversion-tools
BuildRequires:	expect >= 5.40
Requires(pre):	%{?!notmga:rpm-helper}%{?notmga:/usr/sbin/useradd}
Requires(postun):	%{?!notmga:rpm-helper}%{?notmga:/usr/sbin/userdel}
Requires(postun): findutils perl-base

%description
RANCID monitors a router's (or more generally a device's) configuration,
including software and hardware (cards, serial numbers, etc) and uses CVS
(Concurrent Version System) or Subversion  to maintain history of changes.

RANCID does this by the very simple process summarized here:

    * login to each device in the router table (router.db),
    * run various commands to get the information that will be saved,
    * cook the output; re-format, remove oscillating or incrementing data,
    * email any differences (sample) from the previous collection to a mail
      list,
    * and finally commit those changes to the revision control system

RANCID also includes looking glass software. It is based on Ed Kern's looking
glass which was once used for http://nitrous.digex.net/, for the old-school
folks who remember it. Our version has added functions, supports Cisco,
Juniper, and Foundry and uses the login scripts that come with rancid; so it
can use telnet or ssh to connect to your devices(s).

Rancid currently supports Cisco routers, Juniper routers, Catalyst switches,
Foundry switches, Redback NASs, ADC EZT3 muxes, MRTd (and thus likely IRRd),
Alteon switches, and HP Procurve switches and a host of others.

Rancid is known to be used at: AOL, Global Crossing, MFN, NTT America,
Certainty Solutions Inc. 

%package lg
Summary:	Looking Glass CGIs for rancid
# Didn't get picked up automatically
Requires:	perl(LockFile::Simple)

%description lg
This is a looking glass based on Ed Kern's which used to be available on
http://nitrous.digex.net/.  This version supports Cisco, Juniper, and
Foundry, using rancid's [cfj]login to login (so rcmd is not necessary,
it can use telnet, ssh, or rsh), and has some additional commands
implemented.  There are a few Cisco commands where either no Juniper or
Foundry equivalent exists or we have not had time to implement yet.


%prep
%autosetup -p1

cp %{SOURCE1} README.urpmi

# Create a sysusers.d config file
cat >rancid.sysusers.conf <<EOF
u rancid - 'RANCID' %{_localstatedir}/%{name}/ /bin/bash
EOF

%build
%configure
%make_build

%install
mkdir -p %{buildroot}/%{_sysconfdir}/ %{buildroot}/%{_localstatedir}/%{name}
%make_install
perl -pi -e 's/^([^#\$])/# $1/g' %{buildroot}/%{_datadir}/%{name}/cloginrc.sample

perl -pi -e 's,^BASEDIR=%{_localstatedir},BASEDIR=%{_localstatedir}/%{name},g;s,/usr/bin\;,%{_sbindir}\;,' %{buildroot}/%{_sysconfdir}/rancid.conf

# Set up looking glass
mkdir -p %{buildroot}/%{_libexecdir}/%{name}/cgi-bin
mv %{buildroot}/%{_bindir}/lg*.cgi %{buildroot}/%{_libexecdir}/%{name}/cgi-bin
install -D -m 644 %{SOURCE2} %{buildroot}/etc/httpd/conf/sites.d/rancid-lg.conf

rm -f %{buildroot}/%{_datadir}/%{name}/{README.*,CHANGES,COPYING,FAQ,UPGRADING}

mkdir -p %{buildroot}/%{_sysconfdir}/../cron.d/
cat << EOF >> %{buildroot}/%{_sysconfdir}/../cron.d/%{name}
# Rancid cron jobs

# Run config differ hourly
1 * * * * rancid %{_libdir}/rancid/rancid-run

# Clean out config differ logs
50 23 * * * rancid /usr/bin/find /var/lib/rancid/logs -type f -mtime +2 -exec rm {} \;
EOF

install -m0644 -D rancid.sysusers.conf %{buildroot}%{_sysusersdir}/rancid.conf

%pre
%_pre_useradd %{name} %{_localstatedir}/%{name} /bin/false

%postun
%_postun_userdel %{name}

%triggerpostun -- rancid < 3.0
find %{_localstatedir}/%{name} -name 'router.db' -exec perl -p -i.rpmupgrade -e 's/:/;/g' {} \;


%files
%doc README share/README.misc README.urpmi CHANGES FAQ UPGRADING
%license COPYING
%dir %{_sysconfdir}
%config(noreplace) %{_sysconfdir}/rancid.conf
%config(noreplace) %{_sysconfdir}/rancid.types.base
%config(noreplace) %{_sysconfdir}/../cron.d/%{name}
%{_libexecdir}/%{name}/
%exclude %{_libexecdir}/%{name}/cgi-bin
%{_libdir}/%{name}/
%{_datadir}/%{name}/
%exclude %{_datadir}/%{name}/lg.conf.sample
%exclude %{_datadir}/%{name}/lgnotes.html
%attr(750,rancid,rancid) %{_localstatedir}/%{name}
%{_sysusersdir}/rancid.conf
%{_mandir}/man?/*
%exclude %{_mandir}/man5/lg.conf.5*

%files lg
%doc README.lg
%{_datadir}/%{name}/lg.conf.sample
%{_datadir}/%{name}/lgnotes.html
%defattr(-,root,rancid)
%config(noreplace) %{_sysconfdir}/*.conf
%config(noreplace) /etc/httpd/conf/sites.d/rancid-lg.conf
%dir %{_libexecdir}/%{name}/cgi-bin
%{_libexecdir}/%{name}/cgi-bin/lg.cgi
%{_libexecdir}/%{name}/cgi-bin/lgform.cgi
%{_mandir}/man5/lg.conf.5*


%changelog
* Mon Jul 14 2025 daviddavid <daviddavid> 3.13-4.mga10
+ Revision: 2255568
- add fedora patches to fix build
+ umeabot <umeabot>
- Mageia 10 Mass Rebuild

* Sun Sep 29 2024 daviddavid <daviddavid> 3.13-2.mga10
+ Revision: 2101983
- build with our proper build flags

* Sat Sep 10 2022 neoclust <neoclust> 3.13-1.mga9
+ Revision: 1886370
- New version 3.13

* Tue Mar 29 2022 umeabot <umeabot> 3.6.2-3.mga9
+ Revision: 1832052
- Mageia 9 Mass Rebuild

* Fri Feb 14 2020 umeabot <umeabot> 3.6.2-2.mga8
+ Revision: 1519427
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x
- replace deprecated %%makeinstall_std

* Fri Oct 12 2018 tv <tv> 3.6.2-1.mga7
+ Revision: 1319889
- new release
- fix deps

* Sun Sep 23 2018 umeabot <umeabot> 3.4.1-3.mga7
+ Revision: 1300774
- Mageia 7 Mass Rebuild

* Fri Jun 10 2016 luigiwalser <luigiwalser> 3.4.1-2.mga6
+ Revision: 1021057
- fix files lists and duplicate directory conflict between packages

* Sun May 15 2016 buchan <buchan> 3.4.1-1.mga6
+ Revision: 1015808
- New version 3.4.1

* Sat Jan 16 2016 buchan <buchan> 3.2-1.mga6
+ Revision: 923472
- New version 3.2
- New version 3.1
  Handle format change of router.db on upgrade
  Split the looking glass out as a separate package

* Wed Oct 15 2014 umeabot <umeabot> 2.3.8-4.mga5
+ Revision: 739206
- Second Mageia 5 Mass Rebuild

* Fri Sep 26 2014 tv <tv> 2.3.8-3.mga5
+ Revision: 725223
- rebuild for bogus file deps

* Tue Sep 16 2014 umeabot <umeabot> 2.3.8-2.mga5
+ Revision: 688608
- Mageia 5 Mass Rebuild
+ tv <tv>
- s/uggests:/Recommends:/

* Wed Aug 20 2014 buchan <buchan> 2.3.8-1.mga5
+ Revision: 665871
- 2.3.8 with all patches
- imported package rancid


* Wed Jul 28 2010 Guillaume Rousse <guillomovitch@mandriva.org> 2.3.3-1mdv2011.0
+ Revision: 562773
- update to new version 2.3.3

* Fri Aug 21 2009 Guillaume Rousse <guillomovitch@mandriva.org> 2.3.2-1mdv2010.0
+ Revision: 419018
- new version

* Fri Aug 01 2008 Thierry Vignaud <tv@mandriva.org> 2.3.1-4mdv2009.0
+ Revision: 260042
- rebuild

* Fri Jul 25 2008 Thierry Vignaud <tv@mandriva.org> 2.3.1-3mdv2009.0
+ Revision: 247820
- rebuild

* Wed Jan 02 2008 Olivier Blin <oblin@mandriva.com> 2.3.1-1mdv2008.1
+ Revision: 140744
- restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request


* Thu Jan 11 2007 Buchan Milne <bgmilne@mandriva.org> 2.3.1-1mdv2007.0
+ Revision: 107651
- Import rancid

* Tue Jan 09 2007 Buchan Milne <bgmilne@mandriva.org> 2.3.1-1mdv
- initial package
- cron jobs
TODO:
-lg config

